TEXT_COMMENT_OPCODE = 0

SIGNED_EXTERNAL_OPCODE = 0x7369676e

SIGNED_INTERNAL_OPCODE = 0x73696e74

INTERNAL_TRANSFER_OPCODE = 0xae42e5a4

ACTION_SEND_MSG_OPCODE = 0x0ec3c86d
